# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/openmetrics_data_model.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/openmetrics_data_model.proto',
  package='openmetrics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,streamlit/proto/openmetrics_data_model.proto\x12\x0bopenmetrics\x1a\x1fgoogle/protobuf/timestamp.proto\"?\n\tMetricSet\x12\x32\n\x0fmetric_families\x18\x01 \x03(\x0b\x32\x19.openmetrics.MetricFamily\"\x85\x01\n\x0cMetricFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.openmetrics.MetricType\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12$\n\x07metrics\x18\x05 \x03(\x0b\x32\x13.openmetrics.Metric\"]\n\x06Metric\x12\"\n\x06labels\x18\x01 \x03(\x0b\x32\x12.openmetrics.Label\x12/\n\rmetric_points\x18\x02 \x03(\x0b\x32\x18.openmetrics.MetricPoint\"$\n\x05Label\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xae\x03\n\x0bMetricPoint\x12\x32\n\runknown_value\x18\x01 \x01(\x0b\x32\x19.openmetrics.UnknownValueH\x00\x12.\n\x0bgauge_value\x18\x02 \x01(\x0b\x32\x17.openmetrics.GaugeValueH\x00\x12\x32\n\rcounter_value\x18\x03 \x01(\x0b\x32\x19.openmetrics.CounterValueH\x00\x12\x36\n\x0fhistogram_value\x18\x04 \x01(\x0b\x32\x1b.openmetrics.HistogramValueH\x00\x12\x35\n\x0fstate_set_value\x18\x05 \x01(\x0b\x32\x1a.openmetrics.StateSetValueH\x00\x12,\n\ninfo_value\x18\x06 \x01(\x0b\x32\x16.openmetrics.InfoValueH\x00\x12\x32\n\rsummary_value\x18\x07 \x01(\x0b\x32\x19.openmetrics.SummaryValueH\x00\x12-\n\ttimestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x07\n\x05value\"D\n\x0cUnknownValue\x12\x16\n\x0c\x64ouble_value\x18\x01 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"B\n\nGaugeValue\x12\x16\n\x0c\x64ouble_value\x18\x01 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"\x9a\x01\n\x0c\x43ounterValue\x12\x16\n\x0c\x64ouble_value\x18\x01 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x04H\x00\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x08\x65xemplar\x18\x04 \x01(\x0b\x32\x15.openmetrics.ExemplarB\x07\n\x05total\"\x8c\x02\n\x0eHistogramValue\x12\x16\n\x0c\x64ouble_value\x18\x01 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x07\x62uckets\x18\x05 \x03(\x0b\x32\".openmetrics.HistogramValue.Bucket\x1aU\n\x06\x42ucket\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12\x13\n\x0bupper_bound\x18\x02 \x01(\x01\x12\'\n\x08\x65xemplar\x18\x03 \x01(\x0b\x32\x15.openmetrics.ExemplarB\x05\n\x03sum\"k\n\x08\x45xemplar\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05label\x18\x03 \x03(\x0b\x32\x12.openmetrics.Label\"i\n\rStateSetValue\x12\x30\n\x06states\x18\x01 \x03(\x0b\x32 .openmetrics.StateSetValue.State\x1a&\n\x05State\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04name\x18\x02 \x01(\t\"-\n\tInfoValue\x12 \n\x04info\x18\x01 \x03(\x0b\x32\x12.openmetrics.Label\"\xe1\x01\n\x0cSummaryValue\x12\x16\n\x0c\x64ouble_value\x18\x01 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x08quantile\x18\x05 \x03(\x0b\x32\".openmetrics.SummaryValue.Quantile\x1a+\n\x08Quantile\x12\x10\n\x08quantile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01\x42\x05\n\x03sum*{\n\nMetricType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\x0b\n\x07\x43OUNTER\x10\x02\x12\r\n\tSTATE_SET\x10\x03\x12\x08\n\x04INFO\x10\x04\x12\r\n\tHISTOGRAM\x10\x05\x12\x13\n\x0fGAUGE_HISTOGRAM\x10\x06\x12\x0b\n\x07SUMMARY\x10\x07\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_METRICTYPE = _descriptor.EnumDescriptor(
  name='MetricType',
  full_name='openmetrics.MetricType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_SET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HISTOGRAM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE_HISTOGRAM', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUMMARY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1918,
  serialized_end=2041,
)
_sym_db.RegisterEnumDescriptor(_METRICTYPE)

MetricType = enum_type_wrapper.EnumTypeWrapper(_METRICTYPE)
UNKNOWN = 0
GAUGE = 1
COUNTER = 2
STATE_SET = 3
INFO = 4
HISTOGRAM = 5
GAUGE_HISTOGRAM = 6
SUMMARY = 7



_METRICSET = _descriptor.Descriptor(
  name='MetricSet',
  full_name='openmetrics.MetricSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_families', full_name='openmetrics.MetricSet.metric_families', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=157,
)


_METRICFAMILY = _descriptor.Descriptor(
  name='MetricFamily',
  full_name='openmetrics.MetricFamily',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='openmetrics.MetricFamily.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='openmetrics.MetricFamily.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='openmetrics.MetricFamily.unit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='openmetrics.MetricFamily.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='openmetrics.MetricFamily.metrics', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=293,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='openmetrics.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='openmetrics.Metric.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_points', full_name='openmetrics.Metric.metric_points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=388,
)


_LABEL = _descriptor.Descriptor(
  name='Label',
  full_name='openmetrics.Label',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='openmetrics.Label.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='openmetrics.Label.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=426,
)


_METRICPOINT = _descriptor.Descriptor(
  name='MetricPoint',
  full_name='openmetrics.MetricPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown_value', full_name='openmetrics.MetricPoint.unknown_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gauge_value', full_name='openmetrics.MetricPoint.gauge_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counter_value', full_name='openmetrics.MetricPoint.counter_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='histogram_value', full_name='openmetrics.MetricPoint.histogram_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_set_value', full_name='openmetrics.MetricPoint.state_set_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info_value', full_name='openmetrics.MetricPoint.info_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary_value', full_name='openmetrics.MetricPoint.summary_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openmetrics.MetricPoint.timestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='openmetrics.MetricPoint.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=429,
  serialized_end=859,
)


_UNKNOWNVALUE = _descriptor.Descriptor(
  name='UnknownValue',
  full_name='openmetrics.UnknownValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='openmetrics.UnknownValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='openmetrics.UnknownValue.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='openmetrics.UnknownValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=861,
  serialized_end=929,
)


_GAUGEVALUE = _descriptor.Descriptor(
  name='GaugeValue',
  full_name='openmetrics.GaugeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='openmetrics.GaugeValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='openmetrics.GaugeValue.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='openmetrics.GaugeValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=931,
  serialized_end=997,
)


_COUNTERVALUE = _descriptor.Descriptor(
  name='CounterValue',
  full_name='openmetrics.CounterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='openmetrics.CounterValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='openmetrics.CounterValue.int_value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='openmetrics.CounterValue.created', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exemplar', full_name='openmetrics.CounterValue.exemplar', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='total', full_name='openmetrics.CounterValue.total',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1000,
  serialized_end=1154,
)


_HISTOGRAMVALUE_BUCKET = _descriptor.Descriptor(
  name='Bucket',
  full_name='openmetrics.HistogramValue.Bucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='openmetrics.HistogramValue.Bucket.count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper_bound', full_name='openmetrics.HistogramValue.Bucket.upper_bound', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exemplar', full_name='openmetrics.HistogramValue.Bucket.exemplar', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1333,
  serialized_end=1418,
)

_HISTOGRAMVALUE = _descriptor.Descriptor(
  name='HistogramValue',
  full_name='openmetrics.HistogramValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='openmetrics.HistogramValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='openmetrics.HistogramValue.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='openmetrics.HistogramValue.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='openmetrics.HistogramValue.created', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buckets', full_name='openmetrics.HistogramValue.buckets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HISTOGRAMVALUE_BUCKET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='openmetrics.HistogramValue.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1157,
  serialized_end=1425,
)


_EXEMPLAR = _descriptor.Descriptor(
  name='Exemplar',
  full_name='openmetrics.Exemplar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='openmetrics.Exemplar.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openmetrics.Exemplar.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='openmetrics.Exemplar.label', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1534,
)


_STATESETVALUE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='openmetrics.StateSetValue.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='openmetrics.StateSetValue.State.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='openmetrics.StateSetValue.State.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1603,
  serialized_end=1641,
)

_STATESETVALUE = _descriptor.Descriptor(
  name='StateSetValue',
  full_name='openmetrics.StateSetValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='states', full_name='openmetrics.StateSetValue.states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATESETVALUE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1536,
  serialized_end=1641,
)


_INFOVALUE = _descriptor.Descriptor(
  name='InfoValue',
  full_name='openmetrics.InfoValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='openmetrics.InfoValue.info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1643,
  serialized_end=1688,
)


_SUMMARYVALUE_QUANTILE = _descriptor.Descriptor(
  name='Quantile',
  full_name='openmetrics.SummaryValue.Quantile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantile', full_name='openmetrics.SummaryValue.Quantile.quantile', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='openmetrics.SummaryValue.Quantile.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=1909,
)

_SUMMARYVALUE = _descriptor.Descriptor(
  name='SummaryValue',
  full_name='openmetrics.SummaryValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='double_value', full_name='openmetrics.SummaryValue.double_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='openmetrics.SummaryValue.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='openmetrics.SummaryValue.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='openmetrics.SummaryValue.created', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantile', full_name='openmetrics.SummaryValue.quantile', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SUMMARYVALUE_QUANTILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='openmetrics.SummaryValue.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1691,
  serialized_end=1916,
)

_METRICSET.fields_by_name['metric_families'].message_type = _METRICFAMILY
_METRICFAMILY.fields_by_name['type'].enum_type = _METRICTYPE
_METRICFAMILY.fields_by_name['metrics'].message_type = _METRIC
_METRIC.fields_by_name['labels'].message_type = _LABEL
_METRIC.fields_by_name['metric_points'].message_type = _METRICPOINT
_METRICPOINT.fields_by_name['unknown_value'].message_type = _UNKNOWNVALUE
_METRICPOINT.fields_by_name['gauge_value'].message_type = _GAUGEVALUE
_METRICPOINT.fields_by_name['counter_value'].message_type = _COUNTERVALUE
_METRICPOINT.fields_by_name['histogram_value'].message_type = _HISTOGRAMVALUE
_METRICPOINT.fields_by_name['state_set_value'].message_type = _STATESETVALUE
_METRICPOINT.fields_by_name['info_value'].message_type = _INFOVALUE
_METRICPOINT.fields_by_name['summary_value'].message_type = _SUMMARYVALUE
_METRICPOINT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['unknown_value'])
_METRICPOINT.fields_by_name['unknown_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['gauge_value'])
_METRICPOINT.fields_by_name['gauge_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['counter_value'])
_METRICPOINT.fields_by_name['counter_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['histogram_value'])
_METRICPOINT.fields_by_name['histogram_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['state_set_value'])
_METRICPOINT.fields_by_name['state_set_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['info_value'])
_METRICPOINT.fields_by_name['info_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_METRICPOINT.oneofs_by_name['value'].fields.append(
  _METRICPOINT.fields_by_name['summary_value'])
_METRICPOINT.fields_by_name['summary_value'].containing_oneof = _METRICPOINT.oneofs_by_name['value']
_UNKNOWNVALUE.oneofs_by_name['value'].fields.append(
  _UNKNOWNVALUE.fields_by_name['double_value'])
_UNKNOWNVALUE.fields_by_name['double_value'].containing_oneof = _UNKNOWNVALUE.oneofs_by_name['value']
_UNKNOWNVALUE.oneofs_by_name['value'].fields.append(
  _UNKNOWNVALUE.fields_by_name['int_value'])
_UNKNOWNVALUE.fields_by_name['int_value'].containing_oneof = _UNKNOWNVALUE.oneofs_by_name['value']
_GAUGEVALUE.oneofs_by_name['value'].fields.append(
  _GAUGEVALUE.fields_by_name['double_value'])
_GAUGEVALUE.fields_by_name['double_value'].containing_oneof = _GAUGEVALUE.oneofs_by_name['value']
_GAUGEVALUE.oneofs_by_name['value'].fields.append(
  _GAUGEVALUE.fields_by_name['int_value'])
_GAUGEVALUE.fields_by_name['int_value'].containing_oneof = _GAUGEVALUE.oneofs_by_name['value']
_COUNTERVALUE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COUNTERVALUE.fields_by_name['exemplar'].message_type = _EXEMPLAR
_COUNTERVALUE.oneofs_by_name['total'].fields.append(
  _COUNTERVALUE.fields_by_name['double_value'])
_COUNTERVALUE.fields_by_name['double_value'].containing_oneof = _COUNTERVALUE.oneofs_by_name['total']
_COUNTERVALUE.oneofs_by_name['total'].fields.append(
  _COUNTERVALUE.fields_by_name['int_value'])
_COUNTERVALUE.fields_by_name['int_value'].containing_oneof = _COUNTERVALUE.oneofs_by_name['total']
_HISTOGRAMVALUE_BUCKET.fields_by_name['exemplar'].message_type = _EXEMPLAR
_HISTOGRAMVALUE_BUCKET.containing_type = _HISTOGRAMVALUE
_HISTOGRAMVALUE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HISTOGRAMVALUE.fields_by_name['buckets'].message_type = _HISTOGRAMVALUE_BUCKET
_HISTOGRAMVALUE.oneofs_by_name['sum'].fields.append(
  _HISTOGRAMVALUE.fields_by_name['double_value'])
_HISTOGRAMVALUE.fields_by_name['double_value'].containing_oneof = _HISTOGRAMVALUE.oneofs_by_name['sum']
_HISTOGRAMVALUE.oneofs_by_name['sum'].fields.append(
  _HISTOGRAMVALUE.fields_by_name['int_value'])
_HISTOGRAMVALUE.fields_by_name['int_value'].containing_oneof = _HISTOGRAMVALUE.oneofs_by_name['sum']
_EXEMPLAR.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXEMPLAR.fields_by_name['label'].message_type = _LABEL
_STATESETVALUE_STATE.containing_type = _STATESETVALUE
_STATESETVALUE.fields_by_name['states'].message_type = _STATESETVALUE_STATE
_INFOVALUE.fields_by_name['info'].message_type = _LABEL
_SUMMARYVALUE_QUANTILE.containing_type = _SUMMARYVALUE
_SUMMARYVALUE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SUMMARYVALUE.fields_by_name['quantile'].message_type = _SUMMARYVALUE_QUANTILE
_SUMMARYVALUE.oneofs_by_name['sum'].fields.append(
  _SUMMARYVALUE.fields_by_name['double_value'])
_SUMMARYVALUE.fields_by_name['double_value'].containing_oneof = _SUMMARYVALUE.oneofs_by_name['sum']
_SUMMARYVALUE.oneofs_by_name['sum'].fields.append(
  _SUMMARYVALUE.fields_by_name['int_value'])
_SUMMARYVALUE.fields_by_name['int_value'].containing_oneof = _SUMMARYVALUE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['MetricSet'] = _METRICSET
DESCRIPTOR.message_types_by_name['MetricFamily'] = _METRICFAMILY
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['Label'] = _LABEL
DESCRIPTOR.message_types_by_name['MetricPoint'] = _METRICPOINT
DESCRIPTOR.message_types_by_name['UnknownValue'] = _UNKNOWNVALUE
DESCRIPTOR.message_types_by_name['GaugeValue'] = _GAUGEVALUE
DESCRIPTOR.message_types_by_name['CounterValue'] = _COUNTERVALUE
DESCRIPTOR.message_types_by_name['HistogramValue'] = _HISTOGRAMVALUE
DESCRIPTOR.message_types_by_name['Exemplar'] = _EXEMPLAR
DESCRIPTOR.message_types_by_name['StateSetValue'] = _STATESETVALUE
DESCRIPTOR.message_types_by_name['InfoValue'] = _INFOVALUE
DESCRIPTOR.message_types_by_name['SummaryValue'] = _SUMMARYVALUE
DESCRIPTOR.enum_types_by_name['MetricType'] = _METRICTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricSet = _reflection.GeneratedProtocolMessageType('MetricSet', (_message.Message,), {
  'DESCRIPTOR' : _METRICSET,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.MetricSet)
  })
_sym_db.RegisterMessage(MetricSet)

MetricFamily = _reflection.GeneratedProtocolMessageType('MetricFamily', (_message.Message,), {
  'DESCRIPTOR' : _METRICFAMILY,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.MetricFamily)
  })
_sym_db.RegisterMessage(MetricFamily)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.Metric)
  })
_sym_db.RegisterMessage(Metric)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.Label)
  })
_sym_db.RegisterMessage(Label)

MetricPoint = _reflection.GeneratedProtocolMessageType('MetricPoint', (_message.Message,), {
  'DESCRIPTOR' : _METRICPOINT,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.MetricPoint)
  })
_sym_db.RegisterMessage(MetricPoint)

UnknownValue = _reflection.GeneratedProtocolMessageType('UnknownValue', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.UnknownValue)
  })
_sym_db.RegisterMessage(UnknownValue)

GaugeValue = _reflection.GeneratedProtocolMessageType('GaugeValue', (_message.Message,), {
  'DESCRIPTOR' : _GAUGEVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.GaugeValue)
  })
_sym_db.RegisterMessage(GaugeValue)

CounterValue = _reflection.GeneratedProtocolMessageType('CounterValue', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.CounterValue)
  })
_sym_db.RegisterMessage(CounterValue)

HistogramValue = _reflection.GeneratedProtocolMessageType('HistogramValue', (_message.Message,), {

  'Bucket' : _reflection.GeneratedProtocolMessageType('Bucket', (_message.Message,), {
    'DESCRIPTOR' : _HISTOGRAMVALUE_BUCKET,
    '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
    # @@protoc_insertion_point(class_scope:openmetrics.HistogramValue.Bucket)
    })
  ,
  'DESCRIPTOR' : _HISTOGRAMVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.HistogramValue)
  })
_sym_db.RegisterMessage(HistogramValue)
_sym_db.RegisterMessage(HistogramValue.Bucket)

Exemplar = _reflection.GeneratedProtocolMessageType('Exemplar', (_message.Message,), {
  'DESCRIPTOR' : _EXEMPLAR,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.Exemplar)
  })
_sym_db.RegisterMessage(Exemplar)

StateSetValue = _reflection.GeneratedProtocolMessageType('StateSetValue', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATESETVALUE_STATE,
    '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
    # @@protoc_insertion_point(class_scope:openmetrics.StateSetValue.State)
    })
  ,
  'DESCRIPTOR' : _STATESETVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.StateSetValue)
  })
_sym_db.RegisterMessage(StateSetValue)
_sym_db.RegisterMessage(StateSetValue.State)

InfoValue = _reflection.GeneratedProtocolMessageType('InfoValue', (_message.Message,), {
  'DESCRIPTOR' : _INFOVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.InfoValue)
  })
_sym_db.RegisterMessage(InfoValue)

SummaryValue = _reflection.GeneratedProtocolMessageType('SummaryValue', (_message.Message,), {

  'Quantile' : _reflection.GeneratedProtocolMessageType('Quantile', (_message.Message,), {
    'DESCRIPTOR' : _SUMMARYVALUE_QUANTILE,
    '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
    # @@protoc_insertion_point(class_scope:openmetrics.SummaryValue.Quantile)
    })
  ,
  'DESCRIPTOR' : _SUMMARYVALUE,
  '__module__' : 'streamlit.proto.openmetrics_data_model_pb2'
  # @@protoc_insertion_point(class_scope:openmetrics.SummaryValue)
  })
_sym_db.RegisterMessage(SummaryValue)
_sym_db.RegisterMessage(SummaryValue.Quantile)


# @@protoc_insertion_point(module_scope)
