/*! For license information please see 17.9d30345e.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[17],{1505:function(t,e){},1506:function(t,e){},1663:function(t,e){},1823:function(t,e,i){"use strict";i.r(e),i.d(e,"default",(function(){return g}));var n=i(0),a=i(1721),r=i(1661),c=i(24),h=i(212),o=i(8),s=Object(o.a)("div",{target:"e1p558ko0"})((function(t){var e=t.theme;return{paddingTop:e.spacing.sm,"& *":{fontFamily:e.genericFonts.bodyFont,fontSize:"9.6px"},"& svg":{maxWidth:"100%"}}}),""),d=i(1);r.graphviz;var g=Object(h.a)((function(t){var e=t.width,i=t.element,r=t.height,h="graphviz-chart-".concat(i.elementId),o=0,g=0,u=function(){var t=g,n=o;return r?(t=e,n=r):i.useContainerWidth&&(t=e),{chartWidth:t,chartHeight:n}},f=function(){try{var t=Object(a.a)("#".concat(h)).graphviz().zoom(!1).fit(!0).scale(1).renderDot(i.spec).on("end",(function(){var t=Object(a.a)("#".concat(h," > svg")).node();t&&(o=t.getBBox().height,g=t.getBBox().width)})),e=u(),n=e.chartHeight,r=e.chartWidth;n>0&&t.height(n),r>0&&t.width(r)}catch(s){Object(c.b)(s)}};Object(n.useEffect)((function(){f()}));var p=u(),v=p.chartWidth?p.chartWidth:e,b=p.chartHeight?p.chartHeight:r;return Object(d.jsx)(s,{className:"graphviz stGraphVizChart",id:h,style:{width:v,height:b}})}))}}]);