/*! For license information please see 42.ea3be446.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[42],{1836:function(e,t,r){"use strict";r.r(t),r.d(t,"default",(function(){return l}));var i=r(0),n=r(68),c=r(34),s=r(74),a=r(1);var l=function(e){var t=e.disabled,r=e.element,l=e.widgetMgr,o={width:e.width},d=Object(i.useContext)(n.a).getBaseUriParts;return Object(a.jsx)("div",{className:"row-widget stDownloadButton",style:o,children:Object(a.jsx)(c.a,{help:r.help,children:Object(a.jsx)(c.d,{kind:c.b.PRIMARY,size:c.c.SMALL,disabled:t,onClick:function(){l.setTriggerValue(r,{fromUi:!0});var e=document.createElement("a"),t="".concat(Object(s.b)(r.url,d()),"?title=").concat(encodeURIComponent(document.title));e.setAttribute("href",t),e.setAttribute("target","_blank"),e.click()},children:r.label})})})}}}]);