/*! For license information please see 26.48f49d0f.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[26],{1693:function(t,e){},1824:function(t,e,i){"use strict";i.r(e),i.d(e,"default",(function(){return f}));var r,n=i(0),a=i(1664),o=i.n(a),c=i(68),s=i(212),d=i(74),l=i(8),u=Object(l.a)("div",{target:"etr89bj2"})((function(t){var e=t.theme;return{display:"flex",flexDirection:"row",flexWrap:"wrap",paddingTop:e.spacing.sm,rowGap:e.spacing.lg}}),""),h=Object(l.a)("div",{target:"etr89bj1"})((function(t){t.theme;return{display:"flex",flexDirection:"column",alignItems:"stretch",width:"auto",flexGrow:0}}),""),g=Object(l.a)("div",{target:"etr89bj0"})((function(t){var e=t.theme;return{fontFamily:e.genericFonts.bodyFont,fontSize:e.fontSizes.sm,color:e.colors.fadedText60,textAlign:"center",marginTop:e.spacing.xs,wordWrap:"break-word",padding:"0.125rem"}}),""),m=i(1);!function(t){t[t.OriginalWidth=-1]="OriginalWidth",t[t.ColumnWidth=-2]="ColumnWidth",t[t.AutoWidth=-3]="AutoWidth"}(r||(r={}));var f=Object(s.a)((function(t){var e,i=t.width,a=t.isFullScreen,s=t.element,l=t.height,f=Object(n.useContext)(c.a).getBaseUriParts,p=s.width;if(p===r.OriginalWidth||p===r.AutoWidth)e=void 0;else if(p===r.ColumnWidth)e=i;else{if(!(p>0))throw Error("Invalid image width: ".concat(p));e=p}var b={};return l&&a?(b.maxHeight=l,b["object-fit"]="contain"):(b.width=e,p===r.AutoWidth&&(b.maxWidth="100%")),Object(m.jsx)(u,{style:{width:i},children:s.imgs.map((function(t,e){var i=t;return Object(m.jsxs)(h,{"data-testid":"stImage",children:[i.markup?o()(Object(d.g)(i.markup)):Object(m.jsx)("img",{style:b,src:Object(d.b)(i.url,f()),alt:e.toString()}),i.caption&&Object(m.jsx)(g,{"data-testid":"caption",style:b,children:" ".concat(i.caption," ")})]},e)}))})}))}}]);