# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/BackMsg.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from streamlit.proto import ClientState_pb2 as streamlit_dot_proto_dot_ClientState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/BackMsg.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dstreamlit/proto/BackMsg.proto\x1a!streamlit/proto/ClientState.proto\"\xf8\x01\n\x07\x42\x61\x63kMsg\x12\x15\n\x0b\x63lear_cache\x18\x05 \x01(\x08H\x00\x12\x19\n\x0fset_run_on_save\x18\x06 \x01(\x08H\x00\x12\x15\n\x0bstop_script\x18\x07 \x01(\x08H\x00\x12\x1a\n\x10\x63lose_connection\x18\n \x01(\x08H\x00\x12$\n\x0crerun_script\x18\x0b \x01(\x0b\x32\x0c.ClientStateH\x00\x12\x17\n\rload_git_info\x18\x0c \x01(\x08H\x00\x12\x1d\n\x15\x64\x65\x62ug_last_backmsg_id\x18\r \x01(\tB\x06\n\x04typeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nb\x06proto3'
  ,
  dependencies=[streamlit_dot_proto_dot_ClientState__pb2.DESCRIPTOR,])




_BACKMSG = _descriptor.Descriptor(
  name='BackMsg',
  full_name='BackMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_cache', full_name='BackMsg.clear_cache', index=0,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_run_on_save', full_name='BackMsg.set_run_on_save', index=1,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_script', full_name='BackMsg.stop_script', index=2,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_connection', full_name='BackMsg.close_connection', index=3,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rerun_script', full_name='BackMsg.rerun_script', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_git_info', full_name='BackMsg.load_git_info', index=5,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_last_backmsg_id', full_name='BackMsg.debug_last_backmsg_id', index=6,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='BackMsg.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69,
  serialized_end=317,
)

_BACKMSG.fields_by_name['rerun_script'].message_type = streamlit_dot_proto_dot_ClientState__pb2._CLIENTSTATE
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['clear_cache'])
_BACKMSG.fields_by_name['clear_cache'].containing_oneof = _BACKMSG.oneofs_by_name['type']
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['set_run_on_save'])
_BACKMSG.fields_by_name['set_run_on_save'].containing_oneof = _BACKMSG.oneofs_by_name['type']
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['stop_script'])
_BACKMSG.fields_by_name['stop_script'].containing_oneof = _BACKMSG.oneofs_by_name['type']
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['close_connection'])
_BACKMSG.fields_by_name['close_connection'].containing_oneof = _BACKMSG.oneofs_by_name['type']
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['rerun_script'])
_BACKMSG.fields_by_name['rerun_script'].containing_oneof = _BACKMSG.oneofs_by_name['type']
_BACKMSG.oneofs_by_name['type'].fields.append(
  _BACKMSG.fields_by_name['load_git_info'])
_BACKMSG.fields_by_name['load_git_info'].containing_oneof = _BACKMSG.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['BackMsg'] = _BACKMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BackMsg = _reflection.GeneratedProtocolMessageType('BackMsg', (_message.Message,), {
  'DESCRIPTOR' : _BACKMSG,
  '__module__' : 'streamlit.proto.BackMsg_pb2'
  # @@protoc_insertion_point(class_scope:BackMsg)
  })
_sym_db.RegisterMessage(BackMsg)


# @@protoc_insertion_point(module_scope)
