# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/ArrowNamedDataSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from streamlit.proto import Arrow_pb2 as streamlit_dot_proto_dot_Arrow__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/ArrowNamedDataSet.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'streamlit/proto/ArrowNamedDataSet.proto\x1a\x1bstreamlit/proto/Arrow.proto\"I\n\x11\x41rrowNamedDataSet\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08has_name\x18\x03 \x01(\x08\x12\x14\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x06.Arrowb\x06proto3'
  ,
  dependencies=[streamlit_dot_proto_dot_Arrow__pb2.DESCRIPTOR,])




_ARROWNAMEDDATASET = _descriptor.Descriptor(
  name='ArrowNamedDataSet',
  full_name='ArrowNamedDataSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ArrowNamedDataSet.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_name', full_name='ArrowNamedDataSet.has_name', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ArrowNamedDataSet.data', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=145,
)

_ARROWNAMEDDATASET.fields_by_name['data'].message_type = streamlit_dot_proto_dot_Arrow__pb2._ARROW
DESCRIPTOR.message_types_by_name['ArrowNamedDataSet'] = _ARROWNAMEDDATASET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArrowNamedDataSet = _reflection.GeneratedProtocolMessageType('ArrowNamedDataSet', (_message.Message,), {
  'DESCRIPTOR' : _ARROWNAMEDDATASET,
  '__module__' : 'streamlit.proto.ArrowNamedDataSet_pb2'
  # @@protoc_insertion_point(class_scope:ArrowNamedDataSet)
  })
_sym_db.RegisterMessage(ArrowNamedDataSet)


# @@protoc_insertion_point(module_scope)
