/*! For license information please see 30.7ca22af7.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[30],{1822:function(t,e,r){"use strict";r.r(e),r.d(e,"default",(function(){return s}));var i=r(0),n=r(212),c=r(8),o=Object(c.a)("div",{target:"eiqwerr0"})((function(t){return{paddingTop:t.theme.spacing.sm}}),""),a=r(1);var s=Object(n.a)((function(t){var e=t.width,r=t.element,n=t.height,c="bokeh-chart-".concat(r.elementId),s=Object(i.useCallback)((function(){return JSON.parse(r.figure)}),[r]),h=Object(i.useCallback)((function(t){var i=window.Bokeh,o=document.getElementById(c),a=t&&t.doc&&t.doc.roots&&t.doc.roots.references?t.doc.roots.references.find((function(t){return"Plot"===t.type})):void 0;if(a){var s=function(t){var i=t.attributes.plot_width,c=t.attributes.plot_height;return n?(i=e,c=n):r.useContainerWidth&&(i=e),{chartWidth:i,chartHeight:c}}(a),h=s.chartWidth,u=s.chartHeight;h>0&&(a.attributes.plot_width=h),u>0&&(a.attributes.plot_height=u)}null!==o&&(!function(t){for(;t.lastChild;)t.lastChild.remove()}(o),i.embed.embed_item(t,c))}),[e,n,r]);return Object(i.useEffect)((function(){h(s())}),[e,n,r,s,h]),Object(a.jsx)(o,{children:Object(a.jsx)("div",{id:c,className:"stBokehChart"})})}))}}]);