# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/PagesChanged.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from streamlit.proto import AppPage_pb2 as streamlit_dot_proto_dot_AppPage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/PagesChanged.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"streamlit/proto/PagesChanged.proto\x1a\x1dstreamlit/proto/AppPage.proto\"+\n\x0cPagesChanged\x12\x1b\n\tapp_pages\x18\x01 \x03(\x0b\x32\x08.AppPageb\x06proto3'
  ,
  dependencies=[streamlit_dot_proto_dot_AppPage__pb2.DESCRIPTOR,])




_PAGESCHANGED = _descriptor.Descriptor(
  name='PagesChanged',
  full_name='PagesChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_pages', full_name='PagesChanged.app_pages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=112,
)

_PAGESCHANGED.fields_by_name['app_pages'].message_type = streamlit_dot_proto_dot_AppPage__pb2._APPPAGE
DESCRIPTOR.message_types_by_name['PagesChanged'] = _PAGESCHANGED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PagesChanged = _reflection.GeneratedProtocolMessageType('PagesChanged', (_message.Message,), {
  'DESCRIPTOR' : _PAGESCHANGED,
  '__module__' : 'streamlit.proto.PagesChanged_pb2'
  # @@protoc_insertion_point(class_scope:PagesChanged)
  })
_sym_db.RegisterMessage(PagesChanged)


# @@protoc_insertion_point(module_scope)
