/*! For license information please see 29.3c915533.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[29],{1831:function(t,e,r){"use strict";r.r(e),r.d(e,"default",(function(){return n}));var s=r(0),u=r(68),c=r(74),i=r(1);function n(t){var e=t.element,r=t.width,n=Object(s.useRef)(null),a=Object(s.useContext)(u.a).getBaseUriParts;Object(s.useEffect)((function(){n.current&&(n.current.currentTime=e.startTime)}),[e.startTime]);var o=Object(c.b)(e.url,a());return Object(i.jsx)("audio",{id:"audio",ref:n,controls:!0,src:o,className:"stAudio",style:{width:r}})}}}]);