# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/GraphVizChart.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/GraphVizChart.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#streamlit/proto/GraphVizChart.proto\"Z\n\rGraphVizChart\x12\x0c\n\x04spec\x18\x01 \x01(\t\x12\x1b\n\x13use_container_width\x18\x04 \x01(\x08\x12\x12\n\nelement_id\x18\x05 \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\x62\x06proto3'
)




_GRAPHVIZCHART = _descriptor.Descriptor(
  name='GraphVizChart',
  full_name='GraphVizChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='GraphVizChart.spec', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_container_width', full_name='GraphVizChart.use_container_width', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_id', full_name='GraphVizChart.element_id', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=129,
)

DESCRIPTOR.message_types_by_name['GraphVizChart'] = _GRAPHVIZCHART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GraphVizChart = _reflection.GeneratedProtocolMessageType('GraphVizChart', (_message.Message,), {
  'DESCRIPTOR' : _GRAPHVIZCHART,
  '__module__' : 'streamlit.proto.GraphVizChart_pb2'
  # @@protoc_insertion_point(class_scope:GraphVizChart)
  })
_sym_db.RegisterMessage(GraphVizChart)


# @@protoc_insertion_point(module_scope)
