/*! For license information please see 36.941777e7.chunk.js.LICENSE.txt */
(this["webpackJsonpstreamlit-browser"]=this["webpackJsonpstreamlit-browser"]||[]).push([[36],{1834:function(e,t,r){"use strict";r.r(t),r.d(t,"default",(function(){return o}));var a=r(0),n=r(68),i=r(23),s=r(74),c=r(1);function o(e){var t=e.element,r=e.width,o=Object(a.useRef)(null),u=Object(a.useContext)(n.a).getBaseUriParts,l=t.type,d=t.url;Object(a.useEffect)((function(){var e=o.current,r=function(){e&&(e.currentTime=t.startTime)};return e&&e.addEventListener("loadedmetadata",r),function(){e&&e.removeEventListener("loadedmetadata",r)}}),[t]);if(l===i.u.Type.YOUTUBE_IFRAME){var f=0!==r?.75*r:528;return Object(c.jsx)("iframe",{title:d,src:function(e){var r=t.startTime;return r?"".concat(e,"?start=").concat(r):e}(d),width:r,height:f,frameBorder:"0",allow:"autoplay; encrypted-media",allowFullScreen:!0})}return Object(c.jsx)("video",{ref:o,controls:!0,src:Object(s.b)(d,u()),className:"stVideo",style:{width:r,height:0===r?528:void 0}})}}}]);