# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/Element.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from streamlit.proto import Alert_pb2 as streamlit_dot_proto_dot_Alert__pb2
from streamlit.proto import Arrow_pb2 as streamlit_dot_proto_dot_Arrow__pb2
from streamlit.proto import Audio_pb2 as streamlit_dot_proto_dot_Audio__pb2
from streamlit.proto import Balloons_pb2 as streamlit_dot_proto_dot_Balloons__pb2
from streamlit.proto import ArrowVegaLiteChart_pb2 as streamlit_dot_proto_dot_ArrowVegaLiteChart__pb2
from streamlit.proto import BokehChart_pb2 as streamlit_dot_proto_dot_BokehChart__pb2
from streamlit.proto import Button_pb2 as streamlit_dot_proto_dot_Button__pb2
from streamlit.proto import DownloadButton_pb2 as streamlit_dot_proto_dot_DownloadButton__pb2
from streamlit.proto import CameraInput_pb2 as streamlit_dot_proto_dot_CameraInput__pb2
from streamlit.proto import Checkbox_pb2 as streamlit_dot_proto_dot_Checkbox__pb2
from streamlit.proto import ColorPicker_pb2 as streamlit_dot_proto_dot_ColorPicker__pb2
from streamlit.proto import DataFrame_pb2 as streamlit_dot_proto_dot_DataFrame__pb2
from streamlit.proto import DateInput_pb2 as streamlit_dot_proto_dot_DateInput__pb2
from streamlit.proto import DeckGlJsonChart_pb2 as streamlit_dot_proto_dot_DeckGlJsonChart__pb2
from streamlit.proto import DocString_pb2 as streamlit_dot_proto_dot_DocString__pb2
from streamlit.proto import Empty_pb2 as streamlit_dot_proto_dot_Empty__pb2
from streamlit.proto import Exception_pb2 as streamlit_dot_proto_dot_Exception__pb2
from streamlit.proto import Favicon_pb2 as streamlit_dot_proto_dot_Favicon__pb2
from streamlit.proto import FileUploader_pb2 as streamlit_dot_proto_dot_FileUploader__pb2
from streamlit.proto import GraphVizChart_pb2 as streamlit_dot_proto_dot_GraphVizChart__pb2
from streamlit.proto import IFrame_pb2 as streamlit_dot_proto_dot_IFrame__pb2
from streamlit.proto import Image_pb2 as streamlit_dot_proto_dot_Image__pb2
from streamlit.proto import Json_pb2 as streamlit_dot_proto_dot_Json__pb2
from streamlit.proto import NumberInput_pb2 as streamlit_dot_proto_dot_NumberInput__pb2
from streamlit.proto import Markdown_pb2 as streamlit_dot_proto_dot_Markdown__pb2
from streamlit.proto import Metric_pb2 as streamlit_dot_proto_dot_Metric__pb2
from streamlit.proto import MultiSelect_pb2 as streamlit_dot_proto_dot_MultiSelect__pb2
from streamlit.proto import PlotlyChart_pb2 as streamlit_dot_proto_dot_PlotlyChart__pb2
from streamlit.proto import Components_pb2 as streamlit_dot_proto_dot_Components__pb2
from streamlit.proto import Progress_pb2 as streamlit_dot_proto_dot_Progress__pb2
from streamlit.proto import Snow_pb2 as streamlit_dot_proto_dot_Snow__pb2
from streamlit.proto import Spinner_pb2 as streamlit_dot_proto_dot_Spinner__pb2
from streamlit.proto import Radio_pb2 as streamlit_dot_proto_dot_Radio__pb2
from streamlit.proto import Selectbox_pb2 as streamlit_dot_proto_dot_Selectbox__pb2
from streamlit.proto import Slider_pb2 as streamlit_dot_proto_dot_Slider__pb2
from streamlit.proto import Text_pb2 as streamlit_dot_proto_dot_Text__pb2
from streamlit.proto import TextArea_pb2 as streamlit_dot_proto_dot_TextArea__pb2
from streamlit.proto import TextInput_pb2 as streamlit_dot_proto_dot_TextInput__pb2
from streamlit.proto import TimeInput_pb2 as streamlit_dot_proto_dot_TimeInput__pb2
from streamlit.proto import VegaLiteChart_pb2 as streamlit_dot_proto_dot_VegaLiteChart__pb2
from streamlit.proto import Video_pb2 as streamlit_dot_proto_dot_Video__pb2
from streamlit.proto import Heading_pb2 as streamlit_dot_proto_dot_Heading__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/Element.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dstreamlit/proto/Element.proto\x1a\x1bstreamlit/proto/Alert.proto\x1a\x1bstreamlit/proto/Arrow.proto\x1a\x1bstreamlit/proto/Audio.proto\x1a\x1estreamlit/proto/Balloons.proto\x1a(streamlit/proto/ArrowVegaLiteChart.proto\x1a streamlit/proto/BokehChart.proto\x1a\x1cstreamlit/proto/Button.proto\x1a$streamlit/proto/DownloadButton.proto\x1a!streamlit/proto/CameraInput.proto\x1a\x1estreamlit/proto/Checkbox.proto\x1a!streamlit/proto/ColorPicker.proto\x1a\x1fstreamlit/proto/DataFrame.proto\x1a\x1fstreamlit/proto/DateInput.proto\x1a%streamlit/proto/DeckGlJsonChart.proto\x1a\x1fstreamlit/proto/DocString.proto\x1a\x1bstreamlit/proto/Empty.proto\x1a\x1fstreamlit/proto/Exception.proto\x1a\x1dstreamlit/proto/Favicon.proto\x1a\"streamlit/proto/FileUploader.proto\x1a#streamlit/proto/GraphVizChart.proto\x1a\x1cstreamlit/proto/IFrame.proto\x1a\x1bstreamlit/proto/Image.proto\x1a\x1astreamlit/proto/Json.proto\x1a!streamlit/proto/NumberInput.proto\x1a\x1estreamlit/proto/Markdown.proto\x1a\x1cstreamlit/proto/Metric.proto\x1a!streamlit/proto/MultiSelect.proto\x1a!streamlit/proto/PlotlyChart.proto\x1a streamlit/proto/Components.proto\x1a\x1estreamlit/proto/Progress.proto\x1a\x1astreamlit/proto/Snow.proto\x1a\x1dstreamlit/proto/Spinner.proto\x1a\x1bstreamlit/proto/Radio.proto\x1a\x1fstreamlit/proto/Selectbox.proto\x1a\x1cstreamlit/proto/Slider.proto\x1a\x1astreamlit/proto/Text.proto\x1a\x1estreamlit/proto/TextArea.proto\x1a\x1fstreamlit/proto/TextInput.proto\x1a\x1fstreamlit/proto/TimeInput.proto\x1a#streamlit/proto/VegaLiteChart.proto\x1a\x1bstreamlit/proto/Video.proto\x1a\x1dstreamlit/proto/Heading.proto\"\xc2\x0b\n\x07\x45lement\x12\x17\n\x05\x61lert\x18\x1e \x01(\x0b\x32\x06.AlertH\x00\x12\"\n\x10\x61rrow_data_frame\x18( \x01(\x0b\x32\x06.ArrowH\x00\x12\x1d\n\x0b\x61rrow_table\x18\' \x01(\x0b\x32\x06.ArrowH\x00\x12\x34\n\x15\x61rrow_vega_lite_chart\x18) \x01(\x0b\x32\x13.ArrowVegaLiteChartH\x00\x12\x17\n\x05\x61udio\x18\r \x01(\x0b\x32\x06.AudioH\x00\x12\x1d\n\x08\x62\x61lloons\x18\x0c \x01(\x0b\x32\t.BalloonsH\x00\x12\"\n\x0b\x62okeh_chart\x18\x11 \x01(\x0b\x32\x0b.BokehChartH\x00\x12\x19\n\x06\x62utton\x18\x13 \x01(\x0b\x32\x07.ButtonH\x00\x12*\n\x0f\x64ownload_button\x18+ \x01(\x0b\x32\x0f.DownloadButtonH\x00\x12$\n\x0c\x63\x61mera_input\x18- \x01(\x0b\x32\x0c.CameraInputH\x00\x12\x1d\n\x08\x63heckbox\x18\x14 \x01(\x0b\x32\t.CheckboxH\x00\x12$\n\x0c\x63olor_picker\x18# \x01(\x0b\x32\x0c.ColorPickerH\x00\x12\x30\n\x12\x63omponent_instance\x18% \x01(\x0b\x32\x12.ComponentInstanceH\x00\x12 \n\ndata_frame\x18\x03 \x01(\x0b\x32\n.DataFrameH\x00\x12\x1b\n\x05table\x18\x0b \x01(\x0b\x32\n.DataFrameH\x00\x12 \n\ndate_input\x18\x1b \x01(\x0b\x32\n.DateInputH\x00\x12.\n\x12\x64\x65\x63k_gl_json_chart\x18\" \x01(\x0b\x32\x10.DeckGlJsonChartH\x00\x12 \n\ndoc_string\x18\x07 \x01(\x0b\x32\n.DocStringH\x00\x12\x17\n\x05\x65mpty\x18\x02 \x01(\x0b\x32\x06.EmptyH\x00\x12\x1f\n\texception\x18\x08 \x01(\x0b\x32\n.ExceptionH\x00\x12\x1b\n\x07\x66\x61vicon\x18$ \x01(\x0b\x32\x08.FaviconH\x00\x12&\n\rfile_uploader\x18! \x01(\x0b\x32\r.FileUploaderH\x00\x12(\n\x0egraphviz_chart\x18\x12 \x01(\x0b\x32\x0e.GraphVizChartH\x00\x12\x19\n\x06iframe\x18& \x01(\x0b\x32\x07.IFrameH\x00\x12\x1a\n\x04imgs\x18\x06 \x01(\x0b\x32\n.ImageListH\x00\x12\x15\n\x04json\x18\x1f \x01(\x0b\x32\x05.JsonH\x00\x12\x1d\n\x08markdown\x18\x1d \x01(\x0b\x32\t.MarkdownH\x00\x12\x19\n\x06metric\x18* \x01(\x0b\x32\x07.MetricH\x00\x12#\n\x0bmultiselect\x18\x1c \x01(\x0b\x32\x0c.MultiSelectH\x00\x12$\n\x0cnumber_input\x18  \x01(\x0b\x32\x0c.NumberInputH\x00\x12$\n\x0cplotly_chart\x18\x10 \x01(\x0b\x32\x0c.PlotlyChartH\x00\x12\x1d\n\x08progress\x18\x05 \x01(\x0b\x32\t.ProgressH\x00\x12\x17\n\x05radio\x18\x17 \x01(\x0b\x32\x06.RadioH\x00\x12\x1f\n\tselectbox\x18\x19 \x01(\x0b\x32\n.SelectboxH\x00\x12\x19\n\x06slider\x18\x15 \x01(\x0b\x32\x07.SliderH\x00\x12\x15\n\x04snow\x18. \x01(\x0b\x32\x05.SnowH\x00\x12\x1b\n\x07spinner\x18, \x01(\x0b\x32\x08.SpinnerH\x00\x12\x15\n\x04text\x18\x01 \x01(\x0b\x32\x05.TextH\x00\x12\x1e\n\ttext_area\x18\x16 \x01(\x0b\x32\t.TextAreaH\x00\x12 \n\ntext_input\x18\x18 \x01(\x0b\x32\n.TextInputH\x00\x12 \n\ntime_input\x18\x1a \x01(\x0b\x32\n.TimeInputH\x00\x12)\n\x0fvega_lite_chart\x18\n \x01(\x0b\x32\x0e.VegaLiteChartH\x00\x12\x17\n\x05video\x18\x0e \x01(\x0b\x32\x06.VideoH\x00\x12\x1b\n\x07heading\x18/ \x01(\x0b\x32\x08.HeadingH\x00\x42\x06\n\x04typeJ\x04\x08\t\x10\nb\x06proto3'
  ,
  dependencies=[streamlit_dot_proto_dot_Alert__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Arrow__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Audio__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Balloons__pb2.DESCRIPTOR,streamlit_dot_proto_dot_ArrowVegaLiteChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_BokehChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Button__pb2.DESCRIPTOR,streamlit_dot_proto_dot_DownloadButton__pb2.DESCRIPTOR,streamlit_dot_proto_dot_CameraInput__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Checkbox__pb2.DESCRIPTOR,streamlit_dot_proto_dot_ColorPicker__pb2.DESCRIPTOR,streamlit_dot_proto_dot_DataFrame__pb2.DESCRIPTOR,streamlit_dot_proto_dot_DateInput__pb2.DESCRIPTOR,streamlit_dot_proto_dot_DeckGlJsonChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_DocString__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Empty__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Exception__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Favicon__pb2.DESCRIPTOR,streamlit_dot_proto_dot_FileUploader__pb2.DESCRIPTOR,streamlit_dot_proto_dot_GraphVizChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_IFrame__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Image__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Json__pb2.DESCRIPTOR,streamlit_dot_proto_dot_NumberInput__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Markdown__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Metric__pb2.DESCRIPTOR,streamlit_dot_proto_dot_MultiSelect__pb2.DESCRIPTOR,streamlit_dot_proto_dot_PlotlyChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Components__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Progress__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Snow__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Spinner__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Radio__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Selectbox__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Slider__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Text__pb2.DESCRIPTOR,streamlit_dot_proto_dot_TextArea__pb2.DESCRIPTOR,streamlit_dot_proto_dot_TextInput__pb2.DESCRIPTOR,streamlit_dot_proto_dot_TimeInput__pb2.DESCRIPTOR,streamlit_dot_proto_dot_VegaLiteChart__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Video__pb2.DESCRIPTOR,streamlit_dot_proto_dot_Heading__pb2.DESCRIPTOR,])




_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alert', full_name='Element.alert', index=0,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_data_frame', full_name='Element.arrow_data_frame', index=1,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_table', full_name='Element.arrow_table', index=2,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_vega_lite_chart', full_name='Element.arrow_vega_lite_chart', index=3,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio', full_name='Element.audio', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balloons', full_name='Element.balloons', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bokeh_chart', full_name='Element.bokeh_chart', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Element.button', index=7,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_button', full_name='Element.download_button', index=8,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_input', full_name='Element.camera_input', index=9,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkbox', full_name='Element.checkbox', index=10,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_picker', full_name='Element.color_picker', index=11,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_instance', full_name='Element.component_instance', index=12,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_frame', full_name='Element.data_frame', index=13,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='Element.table', index=14,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_input', full_name='Element.date_input', index=15,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deck_gl_json_chart', full_name='Element.deck_gl_json_chart', index=16,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc_string', full_name='Element.doc_string', index=17,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='empty', full_name='Element.empty', index=18,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exception', full_name='Element.exception', index=19,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favicon', full_name='Element.favicon', index=20,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_uploader', full_name='Element.file_uploader', index=21,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='graphviz_chart', full_name='Element.graphviz_chart', index=22,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iframe', full_name='Element.iframe', index=23,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imgs', full_name='Element.imgs', index=24,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='Element.json', index=25,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='markdown', full_name='Element.markdown', index=26,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric', full_name='Element.metric', index=27,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiselect', full_name='Element.multiselect', index=28,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_input', full_name='Element.number_input', index=29,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plotly_chart', full_name='Element.plotly_chart', index=30,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='Element.progress', index=31,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radio', full_name='Element.radio', index=32,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selectbox', full_name='Element.selectbox', index=33,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slider', full_name='Element.slider', index=34,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snow', full_name='Element.snow', index=35,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spinner', full_name='Element.spinner', index=36,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Element.text', index=37,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_area', full_name='Element.text_area', index=38,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_input', full_name='Element.text_input', index=39,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_input', full_name='Element.time_input', index=40,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vega_lite_chart', full_name='Element.vega_lite_chart', index=41,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video', full_name='Element.video', index=42,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='Element.heading', index=43,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='Element.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1397,
  serialized_end=2871,
)

_ELEMENT.fields_by_name['alert'].message_type = streamlit_dot_proto_dot_Alert__pb2._ALERT
_ELEMENT.fields_by_name['arrow_data_frame'].message_type = streamlit_dot_proto_dot_Arrow__pb2._ARROW
_ELEMENT.fields_by_name['arrow_table'].message_type = streamlit_dot_proto_dot_Arrow__pb2._ARROW
_ELEMENT.fields_by_name['arrow_vega_lite_chart'].message_type = streamlit_dot_proto_dot_ArrowVegaLiteChart__pb2._ARROWVEGALITECHART
_ELEMENT.fields_by_name['audio'].message_type = streamlit_dot_proto_dot_Audio__pb2._AUDIO
_ELEMENT.fields_by_name['balloons'].message_type = streamlit_dot_proto_dot_Balloons__pb2._BALLOONS
_ELEMENT.fields_by_name['bokeh_chart'].message_type = streamlit_dot_proto_dot_BokehChart__pb2._BOKEHCHART
_ELEMENT.fields_by_name['button'].message_type = streamlit_dot_proto_dot_Button__pb2._BUTTON
_ELEMENT.fields_by_name['download_button'].message_type = streamlit_dot_proto_dot_DownloadButton__pb2._DOWNLOADBUTTON
_ELEMENT.fields_by_name['camera_input'].message_type = streamlit_dot_proto_dot_CameraInput__pb2._CAMERAINPUT
_ELEMENT.fields_by_name['checkbox'].message_type = streamlit_dot_proto_dot_Checkbox__pb2._CHECKBOX
_ELEMENT.fields_by_name['color_picker'].message_type = streamlit_dot_proto_dot_ColorPicker__pb2._COLORPICKER
_ELEMENT.fields_by_name['component_instance'].message_type = streamlit_dot_proto_dot_Components__pb2._COMPONENTINSTANCE
_ELEMENT.fields_by_name['data_frame'].message_type = streamlit_dot_proto_dot_DataFrame__pb2._DATAFRAME
_ELEMENT.fields_by_name['table'].message_type = streamlit_dot_proto_dot_DataFrame__pb2._DATAFRAME
_ELEMENT.fields_by_name['date_input'].message_type = streamlit_dot_proto_dot_DateInput__pb2._DATEINPUT
_ELEMENT.fields_by_name['deck_gl_json_chart'].message_type = streamlit_dot_proto_dot_DeckGlJsonChart__pb2._DECKGLJSONCHART
_ELEMENT.fields_by_name['doc_string'].message_type = streamlit_dot_proto_dot_DocString__pb2._DOCSTRING
_ELEMENT.fields_by_name['empty'].message_type = streamlit_dot_proto_dot_Empty__pb2._EMPTY
_ELEMENT.fields_by_name['exception'].message_type = streamlit_dot_proto_dot_Exception__pb2._EXCEPTION
_ELEMENT.fields_by_name['favicon'].message_type = streamlit_dot_proto_dot_Favicon__pb2._FAVICON
_ELEMENT.fields_by_name['file_uploader'].message_type = streamlit_dot_proto_dot_FileUploader__pb2._FILEUPLOADER
_ELEMENT.fields_by_name['graphviz_chart'].message_type = streamlit_dot_proto_dot_GraphVizChart__pb2._GRAPHVIZCHART
_ELEMENT.fields_by_name['iframe'].message_type = streamlit_dot_proto_dot_IFrame__pb2._IFRAME
_ELEMENT.fields_by_name['imgs'].message_type = streamlit_dot_proto_dot_Image__pb2._IMAGELIST
_ELEMENT.fields_by_name['json'].message_type = streamlit_dot_proto_dot_Json__pb2._JSON
_ELEMENT.fields_by_name['markdown'].message_type = streamlit_dot_proto_dot_Markdown__pb2._MARKDOWN
_ELEMENT.fields_by_name['metric'].message_type = streamlit_dot_proto_dot_Metric__pb2._METRIC
_ELEMENT.fields_by_name['multiselect'].message_type = streamlit_dot_proto_dot_MultiSelect__pb2._MULTISELECT
_ELEMENT.fields_by_name['number_input'].message_type = streamlit_dot_proto_dot_NumberInput__pb2._NUMBERINPUT
_ELEMENT.fields_by_name['plotly_chart'].message_type = streamlit_dot_proto_dot_PlotlyChart__pb2._PLOTLYCHART
_ELEMENT.fields_by_name['progress'].message_type = streamlit_dot_proto_dot_Progress__pb2._PROGRESS
_ELEMENT.fields_by_name['radio'].message_type = streamlit_dot_proto_dot_Radio__pb2._RADIO
_ELEMENT.fields_by_name['selectbox'].message_type = streamlit_dot_proto_dot_Selectbox__pb2._SELECTBOX
_ELEMENT.fields_by_name['slider'].message_type = streamlit_dot_proto_dot_Slider__pb2._SLIDER
_ELEMENT.fields_by_name['snow'].message_type = streamlit_dot_proto_dot_Snow__pb2._SNOW
_ELEMENT.fields_by_name['spinner'].message_type = streamlit_dot_proto_dot_Spinner__pb2._SPINNER
_ELEMENT.fields_by_name['text'].message_type = streamlit_dot_proto_dot_Text__pb2._TEXT
_ELEMENT.fields_by_name['text_area'].message_type = streamlit_dot_proto_dot_TextArea__pb2._TEXTAREA
_ELEMENT.fields_by_name['text_input'].message_type = streamlit_dot_proto_dot_TextInput__pb2._TEXTINPUT
_ELEMENT.fields_by_name['time_input'].message_type = streamlit_dot_proto_dot_TimeInput__pb2._TIMEINPUT
_ELEMENT.fields_by_name['vega_lite_chart'].message_type = streamlit_dot_proto_dot_VegaLiteChart__pb2._VEGALITECHART
_ELEMENT.fields_by_name['video'].message_type = streamlit_dot_proto_dot_Video__pb2._VIDEO
_ELEMENT.fields_by_name['heading'].message_type = streamlit_dot_proto_dot_Heading__pb2._HEADING
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['alert'])
_ELEMENT.fields_by_name['alert'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['arrow_data_frame'])
_ELEMENT.fields_by_name['arrow_data_frame'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['arrow_table'])
_ELEMENT.fields_by_name['arrow_table'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['arrow_vega_lite_chart'])
_ELEMENT.fields_by_name['arrow_vega_lite_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['audio'])
_ELEMENT.fields_by_name['audio'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['balloons'])
_ELEMENT.fields_by_name['balloons'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['bokeh_chart'])
_ELEMENT.fields_by_name['bokeh_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['button'])
_ELEMENT.fields_by_name['button'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['download_button'])
_ELEMENT.fields_by_name['download_button'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['camera_input'])
_ELEMENT.fields_by_name['camera_input'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['checkbox'])
_ELEMENT.fields_by_name['checkbox'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['color_picker'])
_ELEMENT.fields_by_name['color_picker'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['component_instance'])
_ELEMENT.fields_by_name['component_instance'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['data_frame'])
_ELEMENT.fields_by_name['data_frame'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['table'])
_ELEMENT.fields_by_name['table'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['date_input'])
_ELEMENT.fields_by_name['date_input'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['deck_gl_json_chart'])
_ELEMENT.fields_by_name['deck_gl_json_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['doc_string'])
_ELEMENT.fields_by_name['doc_string'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['empty'])
_ELEMENT.fields_by_name['empty'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['exception'])
_ELEMENT.fields_by_name['exception'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['favicon'])
_ELEMENT.fields_by_name['favicon'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['file_uploader'])
_ELEMENT.fields_by_name['file_uploader'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['graphviz_chart'])
_ELEMENT.fields_by_name['graphviz_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['iframe'])
_ELEMENT.fields_by_name['iframe'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['imgs'])
_ELEMENT.fields_by_name['imgs'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['json'])
_ELEMENT.fields_by_name['json'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['markdown'])
_ELEMENT.fields_by_name['markdown'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['metric'])
_ELEMENT.fields_by_name['metric'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['multiselect'])
_ELEMENT.fields_by_name['multiselect'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['number_input'])
_ELEMENT.fields_by_name['number_input'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['plotly_chart'])
_ELEMENT.fields_by_name['plotly_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['progress'])
_ELEMENT.fields_by_name['progress'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['radio'])
_ELEMENT.fields_by_name['radio'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['selectbox'])
_ELEMENT.fields_by_name['selectbox'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['slider'])
_ELEMENT.fields_by_name['slider'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['snow'])
_ELEMENT.fields_by_name['snow'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['spinner'])
_ELEMENT.fields_by_name['spinner'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['text'])
_ELEMENT.fields_by_name['text'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['text_area'])
_ELEMENT.fields_by_name['text_area'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['text_input'])
_ELEMENT.fields_by_name['text_input'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['time_input'])
_ELEMENT.fields_by_name['time_input'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['vega_lite_chart'])
_ELEMENT.fields_by_name['vega_lite_chart'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['video'])
_ELEMENT.fields_by_name['video'].containing_oneof = _ELEMENT.oneofs_by_name['type']
_ELEMENT.oneofs_by_name['type'].fields.append(
  _ELEMENT.fields_by_name['heading'])
_ELEMENT.fields_by_name['heading'].containing_oneof = _ELEMENT.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['Element'] = _ELEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Element = _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), {
  'DESCRIPTOR' : _ELEMENT,
  '__module__' : 'streamlit.proto.Element_pb2'
  # @@protoc_insertion_point(class_scope:Element)
  })
_sym_db.RegisterMessage(Element)


# @@protoc_insertion_point(module_scope)
